<?php
/**********************************************************
rxFramework.php

info:       Inherit a Smarty class and add new functionality
date:       2006.08.22
author:     Igor Shatokhin
            ICQ:    137-908-479
            E-mail: igshat@gawab.com

***********************************************************/

//
// INCLUDE SMARTY
//
if( !defined('SMARTY_DIR') ) define('SMARTY_DIR', dirname(__FILE__).'/smarty/' );
include_once( SMARTY_DIR.'Smarty.class.php' );

//
// NO MAGIC QUOTES
//
if( get_magic_quotes_gpc() ) {
    _stripslashes_r($_GET);
    _stripslashes_r($_POST);
}

//
// FRAMEWORK CLASS
// reserved template variables:
// $dir, $url, $err, $inf
//
class rxFramework extends Smarty {
    var $dir;       // project root directory
    var $url;       // project root url
    var $rules;     // rules array
    var $rules_vm;  // rules-violate error messages

    //
    // $url : project root url (if no passed will try to determine automatically)
    //
    function rxFramework($url='') {
        // determine root directory and URL
        $this->dir = dirname(__FILE__).'/';
        if($url) $this->url = $url;
        elseif( defined('PROJECT_URL') and PROJECT_URL) $this->url = PROJECT_URL;
        else {
            preg_match("|([^/\\\]*)[/\\\]$|i", $this->dir, $match);
            $this->url = preg_match("|".$match[1]."|i", $_SERVER['REQUEST_URI'])  ?
                preg_replace("|^(.*/".preg_quote($match[1])."/).*$|i", "$1", 'http://'.$_SERVER['HTTP_HOST'].$_SERVER['PHP_SELF'] )
            :   'http://'.$_SERVER['HTTP_HOST'].'/';
        }

        // init Smarty engine
        $this->Smarty();
        $this->template_dir = $this->dir.'templates/';
        $this->compile_dir  = $this->dir.'templates_c/';
        $this->config_dir   = $this->dir.'configs/';
        $this->cache_dir    = $this->dir.'cache/';
        $this->assign_by_ref('dir', $this->dir);
        $this->assign_by_ref('url', $this->url);
        $this->assign('err', array() );
        $this->assign('inf', array() );

        // load rules
        $this->config_load('rules.conf');
        $this->rules = $this->get_config_vars();
        $this->clear_config();
    }

    //
    // Test variable with RegExp rule
    // $var             : variable to test
    // $rule_name       : name of rule
    // $violate_message : append this message to $err variable if rule is violated
    // Return TRUE or FALSE
    //
    function rule(&$var, $rule_name, $violate_message='') {
        if( empty($this->rules[$rule_name]) ) return false;
        if( !preg_match($this->rules[$rule_name],$var) ) {
            $this->err($violate_message);
            return false;
        }
        return true;
    }

    //
    // Check condition
    // $cond        : boolean value
    // $err_message : append this message to $err variable if $cond is FALSE
    // Return $cond or FALSE
    //
    function assert($cond, $err_message='') {
        if( !$cond ) $this->err($err_message);
        return $cond;
    }

    //
    // Add error message to template array $err
    // Return erorr messages count
    //
    function err($mes='') {
        if($mes) $this->append('err', $mes);
        return count( $this->get_template_vars('err') );
    }

    //
    // Add info message to template array $inf
    // Return info messages count
    //
    function inf($mes='') {
        if($mes) $this->append('inf', $mes);
        return count( $this->get_template_vars('inf') );
    }

    //
    // Make $message with config delimiters {#   #} - by default
    //
    function conf($message) {
        return $this->left_delimiter.'#'.$message.'#'.$this->right_delimiter;
    }

    //
    // Add information message with config delimiters {#   #}
    // Return count of info messages
    //
    function conf_err($conf_mes, $before='', $after='') {
        return $this->err( $before.$this->conf($conf_mes).$after );
    }

    //
    // Add information message with config delimiters {#   #}
    // Return count of info messages
    //
    function conf_inf($conf_mes, $before='', $after='') {
        return $this->inf( $before.$this->conf($conf_mes).$after );
    }

    //
    // Safe location header
    //
    function locate($url='') {
        if( !preg_match("|^\w{2,5}://|", $url) )  $url = $this->url . $url;
        header("Location: ".$url);
        die("If you are not automatically redirected, please follow the link: <br><a href=\"".$url."\">$url</a>");
    }
}













//
// recursive stripslashes()
//
function _stripslashes_r(&$var) {
    if( @is_array($var) ) {
        foreach($var as $k=>$v) {
            _stripslashes_r($var[$k]);
        }
    }
    else $var = @stripslashes($var);
}

//
// SAFE VARIABLE
// $var      : link to variable
// $is_unset : value if var is not set
// Return variable
//
function _safe_var(&$var, $is_unset='') {
    if( !isset($var) ) $var = $is_unset;
    return $var;
}

//
// SAFE ARRAY
// $var         : link to variable
// $is_no_array : value if var is not array
// Return array
//
function _safe_array(&$var, $is_no_array=array() ) {
    if( !isset($var) or !is_array($var) ) $var = $is_no_array;
    return $var;
}



?>
